@@ -56,6 +56,8 @@ protected Q_SLOTS:
     void handleHasDefaultRouteChanged(bool);
     virtual void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);
     void activationStateChanged(Knm::InterfaceConnection::ActivationState oldState, Knm::InterfaceConnection::ActivationState newState);
+    void notifyNetworkingState();
+    void connectionChanged();
 
 protected:
     RemoteActivatable *m_activatable;
