@@ -555,7 +555,7 @@ void InterfaceDetailsWidget::handleConnectionStateChange(int new_state, int old_
     } else {
         details->ipAddress = currentIpAddress();
         details->connectionState = static_cast<Solid::Control::NetworkInterfaceNm09::ConnectionState>(new_state);
-        if (reason != Solid::Control::NetworkInterfaceNm09::Unavailable && m_iface->type() == Solid::Control::NetworkInterfaceNm09::Bluetooth) {
+        if (new_state > Solid::Control::NetworkInterfaceNm09::Unavailable && m_iface->type() == Solid::Control::NetworkInterfaceNm09::Bluetooth) {
             QString interfaceName = m_iface->ipInterfaceName();
             if (interfaceName != details->interfaceName) {
                 // Hack to force updating interfaceName and traffic plot source.
@@ -592,15 +592,15 @@ void InterfaceDetailsWidget::setInterface(Solid::Control::NetworkInterfaceNm09*
         showDetails();
         connectSignals();
 
-        QString interfaceName = m_iface->ipInterfaceName();
+        details->interfaceName = m_iface->ipInterfaceName();
         if (details->interfaceName.isEmpty()) {
             details->interfaceName = m_iface->interfaceName();
         }
 
-        m_rxSource = QString("network/interfaces/%1/receiver/data").arg(interfaceName);
-        m_txSource = QString("network/interfaces/%1/transmitter/data").arg(interfaceName);
-        m_rxTotalSource = QString("network/interfaces/%1/receiver/dataTotal").arg(interfaceName);
-        m_txTotalSource = QString("network/interfaces/%1/transmitter/dataTotal").arg(interfaceName);
+        m_rxSource = QString("network/interfaces/%1/receiver/data").arg(details->interfaceName);
+        m_txSource = QString("network/interfaces/%1/transmitter/data").arg(details->interfaceName);
+        m_rxTotalSource = QString("network/interfaces/%1/receiver/dataTotal").arg(details->interfaceName);
+        m_txTotalSource = QString("network/interfaces/%1/transmitter/dataTotal").arg(details->interfaceName);
         m_rxTotal = m_txTotal = 0;
 
         /* Usb network interfaces are hotpluggable and Plasma::DataEngine seems to have difficulty
