@@ -1,5 +1,6 @@
 /*
 Copyright 2008 Will Stephenson <wstephenson@kde.org>
+Copyright 2011-2012 Lamarque V. Souza <lamarque@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -108,6 +109,8 @@ void ConnectionSecretsJob::doAskUser()
         if (uiPlugin && error.isEmpty()) {
             m_settingWidget= uiPlugin->askUser(m_connection, 0);
             buttonCodes = uiPlugin->suggestAuthDialogButtons();
+        } else {
+            kWarning() << "Loading vpn plugin for" << vpnSetting->serviceType() << "failed: " << error;
         }
     } else if ( mSettingName == QLatin1String(NM_SETTING_WIRED_SETTING_NAME)) {
         m_settingWidget = new WiredWidget(m_connection, 0);
